import requests
from datetime import datetime


# Function to fetch set list from StreamerSongList
def fetch_set_list():
    url = "https://api.streamersonglist.com/v1/streamers/21485/playHistory"
    params = {
        "size": "50",
        "current": "0",
        "type": "playedAt",
        "order": "desc",
        "period": "week",
        "songId": "null"
    }

    response = requests.get(url, params=params)

    if response.status_code == 200:
        set_list = response.json().get('items', [])  # Extracting the 'items' key with default empty list
        cleaned_data = []

        for entry in set_list:
            if 'song' in entry:  # Regular song entry
                song_info = entry['song']
                title = song_info.get('title', 'Unknown Title')  # Default to 'Unknown Title' if title is missing
                artist = song_info.get('artist', 'Unknown Artist')  # Default to 'Unknown Artist' if artist is missing
            else:  # Non-list song entry
                title = entry.get('nonlistSong', 'Unknown Title')
                artist = 'Non-Listed'  # You can change this as per your preference

            cleaned_data.append((title, artist))

        # Reverse the order of the songs
        cleaned_data.reverse()

        # Writing cleaned data to a text file
        timestamp = datetime.now().strftime("%Y-%m-%d_%H-%M-%S")
        filename = f"set_list_{timestamp}.txt"
        with open(filename, "w") as file:
            # Write the date at the top of the file
            file.write(f"Date: {set_list[0]['playedAt'][:10]}\n\n")
            # Write songs without repeating the date
            for entry in cleaned_data:
                file.write(f"{entry[0]} - {entry[1]}\n")

        print("Set list saved to:", filename)
        return filename
    else:
        print("Failed to retrieve set list. Status code:", response.status_code)
        return None


# Main function
def main():
    # Fetch set list from StreamerSongList
    file_setlist = fetch_set_list()
    if not file_setlist:
        return


if __name__ == '__main__':
    main()